@@ -1,6 +1,5 @@
 import pyawr.mwoffice as mwo
-from pyawr_utils import vss_utils
-from pyawr_utils import common_utils
+from pyawr_utils import vss_utils, common_utils
 from tkinter import messagebox
 import warnings
 import numpy as np
