@@ -20,10 +20,15 @@ class _Schematics():
 
     def _build_circuit_schematics_dict(self):
         self._circuit_schematics_dict = {}
+        #
+        #
+        #schematic = self._schematics('LPF')
+        #self._circuit_schematics_dict[schematic.Name] = _Schematic(self._schematics(schematic.Name))
+        #
+        #
         for schematic in self._schematics:
             try:
                 self._circuit_schematics_dict[schematic.Name] = _Schematic(self._schematics(schematic.Name))
-
             except:
                 raise RuntimeError('Failed to create circuit schematics dictionary')
 
@@ -123,12 +128,12 @@ class _Schematics():
 #
 #*****************************************************************************************************
 #
-class _Schematic(_Elements): 
+class _Schematic(_Elements, _Equations): 
 
     def __init__(self, circuit_schematic):
         self._circuit_schematic = circuit_schematic
         _Elements.__init__(self, self._circuit_schematic, 'Schematic')
-        #_Equations.__init__(self, self._circuit_schematic)
+        _Equations.__init__(self, self._circuit_schematic)
         
 
     @property
